%global momorel 13
# Requires completely version matching of cfitsio
%global cfitsiover 3.250
%global qtver 3.3.7
%global kdever 3.5.10
%global kdelibsrel 6m
%global qtdir %{_libdir}/qt3
%global kdedir /usr
%global enable_gcc_check_and_hidden_visibility 0

Summary: A data viewing program for KDE
Name: kst
Version: 1.8.0
Release: %{momorel}m%{?dist}
License: GPLv3
Group: Applications/Engineering
URL: http://kst.kde.org/
Source0: ftp://ftp.kde.org/pub/kde/stable/apps/KDE3.x/scientific/%{name}-%{version}.tar.gz
NoSource: 0
Patch0: %{name}-except.diff
Patch1: %{name}-1.7.0-automake111.patch
Patch2: %{name}-%{version}-autoconf265.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: kdelibs3 >= %{kdever}-%{kdelibsrel}
Requires: cfitsio = %{cfitsiover}
Requires: netcdf
BuildRequires: qt3-devel >= %{qtver}
BuildRequires: kdelibs3-devel >= %{kdever}-%{kdelibsrel}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: cfitsio-devel = %{cfitsiover}
BuildRequires: coreutils
BuildRequires: desktop-file-utils
BuildRequires: getdata-devel
BuildRequires: gettext
BuildRequires: gsl-devel
BuildRequires: libtool
BuildRequires: muParser-devel
BuildRequires: ncurses-devel
BuildRequires: netcdf-devel >= 4.1.1
BuildRequires: readline-devel

%description
Kst is a real-time data viewing and plotting tool with basic data analysis 
functionality. Kst contains many powerful built-in features and is 
expandable with plugins and extensions. Kst is a KDE application.

Main features of kst include:
  * Robust plotting of live "streaming" data.
  * Powerful keyboard and mouse plot manipulation.
  * Powerful plugins and extensions support.
  * Large selection of built-in plotting and data manipulation functions, 
    such as histograms, equations, and power spectra.
  * Color mapping and contour mapping capabilities for three-dimensional data.
  * Monitoring of events and notifications support.
  * Filtering and curve fitting capabilities.
  * Convenient command-line interface.
  * Powerful graphical user interface.
  * Support for several popular data formats.
  * Multiple tabs or windows.

%package docs
Summary: Documentation for kst
Group: Applications/Engineering
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description docs
Documentation, tutorial, and sample data for kst.

%package devel
Summary: Development libraries and headers for kst
Group: Applications/Engineering
Requires: %{name} = %{version}-%{release}

%description devel
Headers and libraries required when building against kst.

%package netcdf
Summary: netcdf datasource plugin for kst
Group: Applications/Engineering
Requires: %{name} = %{version}-%{release}

%description netcdf
A plugin allowing kst to open and read data in netcdf format.

%package fits
Summary: fits datasource plugin for kst
Group: Applications/Engineering
Requires: %{name} = %{version}-%{release}
# Hack because cfitsio won't run if it's internal library version
# doesn't perfectly match between installed library and compiled
# against library.  Meh.
Requires: cfitsio = %{cfitsiover}

%description fits
A plugin allowing kst to open and read data and images contained within 
fits files.  This includes healpix encoded fits files, and lfiio data.

%package getdata
Summary: getdata datasource plugin for kst
Group: Applications/Engineering
Requires: %{name} = %{version}-%{release}

%description getdata
A plugin allowing kst to open and read data in getdata (dirfile) format.

%prep
%setup -q

%patch0 -p1 -b .except 
%patch1 -p1 -b .automake111
%patch2 -p1 -b .autoconf265

make -f admin/Makefile.common cvs

%build
export QTDIR=%{qtdir} KDEDIR=%{kdedir} QTLIB=%{qtdir}/lib

CFLAGS="%{optflags}" \
CXXFLAGS="%{optflags}" \
./configure \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--includedir=%{_includedir}/kde \
	--mandir=%{_mandir} \
	--with-qt-libraries=%{qtdir}/lib \
	--with-extra-includes=%{_includedir}/kde:%{_includedir}/cfitsio \
	--with-extra-libs=%{_libdir}/kde3:%{_libdir}/netcdf \
	--enable-new-ldflags \
%if %{enable_gcc_check_and_hidden_visibility}
	--enable-gcc-hidden-visibility \
%endif
	--disable-debug \
	--disable-warnings \
	--disable-rpath \
	--disable-dependency-tracking \
	--disable-static

make %{?_smp_mflags}

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

# Delete wmap and scuba2 datasources; it's a packaging bug at the 
# kst upstream end that they are installed in 1.8.0 (they are unfinished?).
rm -f  %{buildroot}%{_libdir}/kde3/%{name}data_scuba.la \
       %{buildroot}%{_libdir}/kde3/%{name}data_scuba.so \
       %{buildroot}%{_libdir}/kde3/%{name}data_wmap.la \
       %{buildroot}%{_libdir}/kde3/%{name}data_wmap.so \
       %{buildroot}%{_libdir}/kde3/%{name}data_planckIDEF.so \
       %{buildroot}%{_libdir}/kde3/%{name}data_planckIDEF.la \
       %{buildroot}%{_datadir}/services/%{name}/%{name}data_scuba.desktop \
       %{buildroot}%{_datadir}/services/%{name}/%{name}data_wmap.desktop \
       %{buildroot}%{_datadir}/services/%{name}/%{name}data_planckIDEF.desktop \
       %{buildroot}%{_datadir}/applications/kde/%{name}.desktop

%find_lang %{name}

# Make documentation symlinks relative
for x in %{buildroot}%{_defaultdocdir}/HTML/*/%{name}/
do
  ln -sf ../common $x
done

# install desktop file
desktop-file-install --vendor= --delete-original \
  --dir %{buildroot}%{_datadir}/applications/kde \
  --remove-category Utility  \
  --add-category Graphics \
  %{buildroot}%{_datadir}/applications/%{name}.desktop

# clean up old desktop file
rm -rf %{buildroot}%{_datadir}/applnk/Graphics

# link icon
mkdir -p %{buildroot}%{_datadir}/pixmaps
ln -s ../icons/locolor/32x32/apps/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%post
/sbin/ldconfig

%postun
/sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING INSTALL README
%doc %{name}/COPYING* %{name}/NEWS %{name}/RELEASE.NOTES
# binaries
%{_bindir}/%{name}
%{_bindir}/%{name}cmd
%{_bindir}/d2asc
# libraries
%{_libdir}/lib*.so.*
%{_libdir}/lib*.la
# update
%{_datadir}/apps/kconf_update/%{name}autosave11.upd
%{_datadir}/apps/kconf_update/%{name}rcmisc11.upd
# fonts
%dir %{_datadir}/apps/%{name}
%{_datadir}/apps/%{name}/fonts
# data plugins
%{_libdir}/kde3/%{name}data_ascii.*
%{_libdir}/kde3/%{name}data_frame.*
%{_libdir}/kde3/%{name}data_indirect.*
%{_libdir}/kde3/%{name}data_qimagesource.*
%{_datadir}/services/%{name}/%{name}data_ascii.desktop
%{_datadir}/services/%{name}/%{name}data_frame.desktop
%{_datadir}/services/%{name}/%{name}data_indirect.desktop
%{_datadir}/services/%{name}/%{name}data_qimagesource.desktop
%{_datadir}/services/%{name}/%{name}object_*.desktop
%{_datadir}/servicetypes/%{name}/%{name}datasourceplugin.desktop
%{_datadir}/servicetypes/%{name}/%{name}basicplugin.desktop
%{_datadir}/servicetypes/%{name}/%{name}dataobjectplugin.desktop
# plugins
%{_libdir}/kde3/%{name}plugins
%{_libdir}/kde3/%{name}object_*
%dir %{_datadir}/servicetypes/%{name}
%{_datadir}/servicetypes/%{name}/%{name}plugin.desktop
%{_datadir}/servicetypes/%{name}/%{name}filter.desktop
%{_libdir}/kde3/plugins/designer/*
# extensions
%{_libdir}/kde3/%{name}extension_*
%dir %{_datadir}/services/%{name}
%{_datadir}/services/%{name}/%{name}extension_*.desktop
%{_datadir}/apps/%{name}/%{name}extension_*.rc
%{_datadir}/servicetypes/%{name}/%{name}extension.desktop
# UI file
%{_datadir}/apps/%{name}/%{name}ui.rc
# desktop file
%{_datadir}/mimelnk/application/x-%{name}.desktop
%{_datadir}/applications/kde/%{name}.desktop
# icons
%{_datadir}/icons/hicolor/22x22/actions/*.png
%{_datadir}/icons/locolor/16x16/apps/%{name}.png
%{_datadir}/icons/locolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/16x16/mimetypes/%{name}.png
%{_datadir}/icons/hicolor/32x32/mimetypes/%{name}.png
%{_datadir}/icons/locolor/16x16/mimetypes/%{name}.png
%{_datadir}/icons/locolor/32x32/mimetypes/%{name}.png
%{_datadir}/apps/%{name}/pics/*.png
%{_datadir}/pixmaps/%{name}.png
# other
%{_datadir}/config/colors/*
%{_mandir}/man1/%{name}.1.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/kde/%{name}datasource.h
%{_includedir}/kde/%{name}object.h
%{_includedir}/kde/%{name}_export.h
%{_includedir}/kde/%{name}sharedptr.h
%{_includedir}/kde/rwlock.h
%{_includedir}/kde/%{name}dateparser.h
%{_includedir}/kde/%{name}waitcondition.h
%{_includedir}/kde/%{name}ext*.h
%{_includedir}/kde/%{name}objectcollection.h
%{_libdir}/lib*.so

%files docs
%defattr(-,root,root,-)
%{_datadir}/doc/HTML/*/%{name}
%{_datadir}/apps/%{name}/tutorial

%files fits
%defattr(-,root,root,-)
%{_libdir}/kde3/%{name}data_fitsimage.*
%{_libdir}/kde3/%{name}data_healpix.*
%{_libdir}/kde3/%{name}data_lfiio.*
%{_datadir}/services/%{name}/%{name}data_fitsimage.desktop
%{_datadir}/services/%{name}/%{name}data_healpix.desktop
%{_datadir}/services/%{name}/%{name}data_lfiio.desktop

%files netcdf
%defattr(-,root,root,-)
%{_libdir}/kde3/%{name}data_netcdf.*
%{_datadir}/services/%{name}/%{name}data_netcdf.desktop

%files getdata
%defattr(-,root,root,-)
%{_libdir}/kde3/%{name}data_dirfile.*
%{_datadir}/services/%{name}/%{name}data_dirfile.desktop

%changelog
* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (1.8.0-13m)
- full rebuild for mo7 release

* Sat Jul 31 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (1.8.0-12m)
- rebuild against netcdf-4.1.1

* Fri Jul  2 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (1.8.0-11m)
- rebuild against cfitsio-3.250

* Sun May 23 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.8.0-10m)
- import arts-acinclude.patch as autoconf265.patch from F-13
- fix build with new autoconf

* Tue May 04 2010 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.8.0-9m)
- rebuild against readline6

* Fri Apr 23 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.8.0-8m)
- touch up spec file

* Thu Jan 28 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.8.0-7m)
- rewind desktop-file-install section to 1.6.0-1m
  fix up duplicate menu entries and move kst.desktop to correct space again
- sort %%doc again

* Thu Jan 28 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (1.8.0-6m)
- build with getdata

* Thu Jan 28 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (1.8.0-5m)
- rebuild against cfitsio-3.240
- sync with Fedora devel (separate some subpackages)

* Sun Jan 10 2010 NARITA Koichi <pulsar@momonga-linux.org>
- (1.8.0-4m)
- rebuild against cfitsio-3.230

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.8.0-3m)
- rebuild against gcc-4.4 and glibc-2.11

* Wed Oct 28 2009 NARITA Koichi <pulsar@momonga-linux.org>
- (1.8.0-2m)
- rebuild against cfitsio-3.210

* Sun Sep 13 2009 NARITA Koichi <pulsar@momonga-linux.org>
- (1.8.0-1m)
- update to 1.8.0
- rebuild against cfitsio-3.200

* Sun Jun 14 2009 NARITA Koichi <pulsar@momonga-linux.org>
- (1.7.0-6m)
- rebuild against cfitsio-3.181-1m

* Wed May 20 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.7.0-5m)
- fix build with new automake

* Sun Apr 26 2009 NARITA Koichi <pulsar@momonga-linux.org>
- (1.7.0-4m)
- rebuild against cfitsio-3.140

* Sat Feb 14 2009 NARITA Koichi <pulsar@momonga-linux.org>
- (1.7.0-3m)
- rebuild against cfitsio-3.130

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.7.0-2m)
- rebuild against rpm-4.6

* Fri Nov  7 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (1.7.0-1m)
- update to 1.7.0
- rebuild against cfitsio-3.100

* Sun May 18 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.6.0-3m)
- revise %%{_docdir}/HTML/*/kst/common

* Fri May 16 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.6.0-2m)
- modify %%files for smart handling of a directory

* Fri May 16 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.6.0-1m)
- initial package for Momonga Linux
